``apptainer`` Installation
--------------------------

The installation instructions from precompiled binaries are detailed `here <https://apptainer.org/docs/admin/main/installation.html#installation-on-linux>`__ for both Debian, Ubuntu, and CentOS.
